summaryrefslogtreecommitdiffstats
path: root/packages/base/src/files/install/mysql/data/171001_upgrade_script.sql
diff options
context:
space:
mode:
Diffstat (limited to 'packages/base/src/files/install/mysql/data/171001_upgrade_script.sql')
-rw-r--r--packages/base/src/files/install/mysql/data/171001_upgrade_script.sql8
1 files changed, 4 insertions, 4 deletions
diff --git a/packages/base/src/files/install/mysql/data/171001_upgrade_script.sql b/packages/base/src/files/install/mysql/data/171001_upgrade_script.sql
index 6be2f25c5..c6f6303bd 100644
--- a/packages/base/src/files/install/mysql/data/171001_upgrade_script.sql
+++ b/packages/base/src/files/install/mysql/data/171001_upgrade_script.sql
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
* ECOMP Policy Engine
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -17,10 +17,10 @@
* limitations under the License.
* ============LICENSE_END=========================================================
*/
-use ecomp_sdk;
-drop table if exists `ecomp_sdk`.`rainydaytreatments`;
+use onap_sdk;
+drop table if exists `onap_sdk`.`rainydaytreatments`;
-CREATE TABLE `ecomp_sdk`.`rainydaytreatments` (
+CREATE TABLE `onap_sdk`.`rainydaytreatments` (
`id` int(11) NOT NULL AUTO_INCREMENT,
`bbid` varchar(250) DEFAULT NULL,
`workstep` varchar(250) DEFAULT NULL,
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
-* ECOMP Policy Engine
+* ONAP Policy Engine
* ================================================================================
* Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.